aboutsummaryrefslogtreecommitdiff
path: root/src/modules/sdlog2/sdlog2.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/sdlog2/sdlog2.c')
-rw-r--r--src/modules/sdlog2/sdlog2.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/modules/sdlog2/sdlog2.c b/src/modules/sdlog2/sdlog2.c
index 16ca72891..efd6594b5 100644
--- a/src/modules/sdlog2/sdlog2.c
+++ b/src/modules/sdlog2/sdlog2.c
@@ -1860,9 +1860,9 @@ int check_free_space()
return ERROR;
}
- /* use a threshold of 4 MiB */
- if (statfs_buf.f_bavail < (int)(4*1024*1024/statfs_buf.f_bsize)) {
- warnx("no more space on MicroSD (less than 4 MiB)");
+ /* use a threshold of 10 MiB */
+ if (statfs_buf.f_bavail < (int)(10*1024*1024/statfs_buf.f_bsize)) {
+ warnx("no more space on MicroSD (less than 10 MiB)");
mavlink_log_critical(mavlink_fd, "[sdlog2] no more space left on MicroSD");
/* we do not need a flag to remember that we sent this warning because we will exit anyway */
return ERROR;